@@ -3,8 +3,8 @@
 # column of w for the data n-vector x
 
 subroutine jacklins(x, w, n, k, res)
-integer n, k, l
-real*8 x(n), w(n-1,k), res(n,k)
+INTEGER n, k, l
+DOUBLE PRECISION x(n), w(n-1,k), res(n,k)
 
 do l=1,k {
   do j=1,n {
